const express = require("express");
const session = require("express-session");
const cors = require("cors");
require("dotenv").config();
const userRoutes = require("./routes/userRoutes");

// create connection to db and initialize table schema
const { pool } = require("./config/database/database.config");
const DatabaseInitializer = require("./config/database/databaseInitializer");

const app = express();
app.use(express.json());
app.use(cors());
app.use(
  session({
    secret: "this is totally secret",
    resave: false,
    saveUninitialized: false,
    cookie: { secure: true },
  })
);

// establish port
const port = process.env.PORT || 3000;

// set up CAS
const passport = require("passport");
const casStrategy = require("./config/auth/auth.cas");
const peopleRouter = require("./routes/peopleRoutes");
app.use(passport.initialize());
app.use(passport.session());
passport.use(casStrategy);
passport.serializeUser(function (user, done) {
  done(null, user.username);
});
passport.deserializeUser(function (username, done) {
  done(null, {
    username,
  });
});

// Set Current User
app.use(function (req, res, next) {
  res.locals.currentUser = req.user;
  next();
});

// import routes
require("./config/auth/auth.routes")(app);
app.use("/api/user", userRoutes);
app.use("/api/person", peopleRouter);

// Basic route to check if server is running
app.get("/api", (req, res) => {
  res.send("Hello World! This app is running.");
});

// Initialize test users and start the server
async function initializeApp() {
  const dbInitializer = new DatabaseInitializer(pool);
  await dbInitializer.initializeAll(); // populate roles and test users

  app.listen(port, () => {
    console.log(`Server is running on port ${port}`);
  });
}

initializeApp();
