const { pool } = require("../config/database/database.config");

/*
Add address info into address table and peopleXaddress table
*/
async function addAddress(address, peopleId) {
  // get all the parts of the address
  let { address1, address2, city, state, country, zipCode, preferredAddress } =
    address;

  console.log("adding address...");

  try {
    // Use helper functions to look up stateId and countryId
    const stateId = await _lookupStateId(state);
    const countryId = await _lookupCountryId(country);

    // query for adding the address
    const query = `
      INSERT INTO address (address1, address2, city, stateId, countryId, zipCode)
      VALUES (?,?,?,?,?,?)
    `;

    // insert data into the address table
    const [addressResult] = await pool.query(query, [
      address1,
      address2,
      city,
      stateId,
      countryId,
      zipCode,
    ]);

    // get the id of the newly created address in the DB
    const addressId = addressResult.insertId;

    console.log(
      "successfully inserted addressID " +
        addressId +
        " for person: " +
        peopleId
    );

    // Now insert into the peopleXAddress table
    const peopleAddressQuery = `
        INSERT INTO peopleXAddress (peopleId, addressId, preferredAddress)
        VALUES (?, ?, ?)
    `;
    const [peopleAddressResult] = await pool.query(peopleAddressQuery, [
      peopleId,
      addressId,
      preferredAddress,
    ]);

    console.log("Added into peopleXaddress");

    return peopleAddressResult;
  } catch (error) {
    // return null if error
    console.error(error);
    return null;
  }
}

// Private helper function to look up the stateId
async function _lookupStateId(state) {
  // for now return 1 while tables are not populated
  return 1;

  // try {
  //   const lookupQuery = `
  //     SELECT stateId FROM stateLookup WHERE name = ?
  //   `;
  //   const [lookupResults] = await pool.query(lookupQuery, [state]);

  //   if (lookupResults.length === 0) {
  //     console.log("State not found");
  //     return null;
  //   }

  //   return lookupResults[0].stateId;
  // } catch (error) {
  //   console.error(`Error looking up state: ${state}`, error);
  //   throw error;
  // }
}

// Private helper function to look up the countryId
async function _lookupCountryId(country) {
  // for now return 1 while tables are not populated
  return 1;

  // try {
  //   const lookupQuery = `
  //     SELECT countryId FROM countryLookup WHERE name = ?
  //   `;
  //   const [lookupResults] = await pool.query(lookupQuery, [country]);
  //   if (lookupResults.length === 0) {
  //     console.log("Country not found");
  //     return null;
  //   }
  //   return lookupResults[0].countryId;
  // } catch (error) {
  //   console.error(`Error looking up country: ${country}`, error);
  //   throw error;
  // }
}

module.exports = { addAddress };
