const { pool } = require("../config/database/database.config");

/*
Class responsible for making queries to the 
rolesPermissions database.
*/

/*
Function to add a role to the database

permissionLevel and permissionDescription must both be strings.
*/
async function addRoleIfNotExists(
  roleID,
  permissionLevel,
  permissionDescription
) {
  console.log("adding role: ", permissionLevel);

  // do not add role if it already exists
  const existingRole = await getRole(roleID);
  if (existingRole) {
    console.log("Role already exists: ", permissionLevel);
    return;
  }

  // insert SQL query
  const query = `INSERT INTO rolesPermissions (roleID, permissionLevel, permissionLevelDescription)
    VALUES (?, ?, ?)`;

  // attempt to insert role into table
  try {
    await pool.query(query, [roleID, permissionLevel, permissionDescription]);
    console.log(`Successfully added role: ${permissionLevel}`);
  } catch (error) {
    console.error(`Error adding role: ${permissionLevel}`, error);
    throw error;
  }
}

async function getRole(roleId) {
  // SQL query to get a certain role
  const query = "SELECT * FROM rolesPermissions WHERE roleID = ?";

  try {
    console.log("Getting role: ", roleId);

    const [rows] = await pool.query(query, [roleId]);
    if (rows.length > 0) {
      console.log("Found role: ", roleId);
      return rows[0]; // Return the role if found
    } else {
      console.log("Role not found: ", roleId);
      return null; // Return null if no role is found
    }
  } catch (error) {
    console.error(`Error fetching role with ID ${roleId}:`, error);
    throw error;
  }
}

module.exports = { addRoleIfNotExists, getRole };
