const { pool } = require("../config/database/database.config");

/*
Class responsible for interacting with the users table
and making queries to it.
*/

/*
Find user info by their username.
*/
async function findByUsername(username) {
  try {
    console.log("Finding user:", username);

    // include permission level in response
    const [results] = await pool.query(
      `SELECT users.*, rolesPermissions.permissionLevel
       FROM users
       JOIN rolesPermissions ON users.roleID = rolesPermissions.roleID
       WHERE users.username = ?`,
      [username]
    );

    console.log("Query completed. Results:", results);

    // Return the first result if found, otherwise return null
    return results.length > 0 ? results[0] : null;
  } catch (err) {
    console.error("Database error in findByUsername:", err);
    throw err; // Propagate the error
  }
}

/*
Function to add user to the repository
*/
async function addUser(username, roleID) {
  try {
    console.log("adding user: ", username);

    const [results] = await pool.query(
      "INSERT INTO users (username, roleID) VALUES (?, ?)",
      [username, roleID]
    );

    console.log("completed adding user: ", results);

    return true;
  } catch (error) {
    console.error("Error adding user: ", username);
    throw error;
  }
}

module.exports = { findByUsername, addUser };
