// Mock the database's pool and query function
jest.mock("../../config/database/database.config", () => {
  const queryMock = jest.fn(); // Mock query function
  return { pool: { query: queryMock } }; // Return the mocked pool directly
});

const { pool } = require("../../config/database/database.config");
const { addAddress } = require("../../repository/addressRepository");

/*
Test methods for addressRepository
*/
describe("Testing addressRepository.js", () => {
  const mockAddress1 = {
    address1: "123 Main St",
    address2: "Apt 4",
    city: "Springfield",
    state: "VA",
    country: "United States",
    zipCode: "22150",
    preferredAddress: true,
  };

  const mockAddress2 = {
    address1: "12 Center St",
    address2: "Apt 14",
    city: "Centerville",
    state: "VA",
    country: "United States",
    zipCode: "23456",
    preferredAddress: true,
  };

  const mockPeopleId = 1;

  describe("addAddress tests", () => {
    it("Insert 1 address with no errors", async () => {
      const mockAddressId = 2;
      const mockPeopleXAddressResult = { affectedRows: 1 };

      // Mock database query for inserting address and peopleXAddress
      pool.query
        .mockResolvedValueOnce([{ insertId: mockAddressId }]) // First query for address insertion
        .mockResolvedValueOnce([mockPeopleXAddressResult]); // Second query for peopleXAddress insertion

      const result = await addAddress(mockAddress1, mockPeopleId);

      // Verify first query was called for address table
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        "123 Main St",
        "Apt 4",
        "Springfield",
        1, // Hardcoded for now
        1, // Hardcoded fow now
        "22150",
      ]);

      // Verify second query was called for peopleXAddress table
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        mockPeopleId,
        mockAddressId, // ensure the correct addressID was used
        true,
      ]);

      // Expect the function to return the result of the second query
      expect(result).toBe(mockPeopleXAddressResult);
    });

    it("should handle errors during address insertion", async () => {
      // Mock database query to throw an error during address insertion
      const mockError = new Error("Database query failed");
      pool.query.mockRejectedValueOnce(mockError);

      // Call addAddress and expect it to handle the error
      const result = await addAddress(mockAddress1, mockPeopleId);

      expect(result).toBe(null);
    });

    it("Insert 1 address with no errors", async () => {
      const mockAddressId = 2;
      const mockPeopleXAddressResult = { affectedRows: 1 };

      // Mock database query for inserting address and peopleXAddress
      pool.query.mockResolvedValueOnce([{ insertId: mockAddressId }]); // First query for address insertion

      // Mock second query to throw an error during peopleXAddress insertion
      const mockError = new Error("Failed to insert into peopleXAddress");
      pool.query.mockRejectedValueOnce(mockError);

      const result = await addAddress(mockAddress1, mockPeopleId);

      // Verify first query was called for address table
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        "123 Main St",
        "Apt 4",
        "Springfield",
        1, // Hardcoded for now
        1, // Hardcoded fow now
        "22150",
      ]);

      // Verify second query was called for peopleXAddress table
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        mockPeopleId,
        mockAddressId, // ensure the correct addressID was used
        true,
      ]);

      // expect a null return after the call
      expect(result).toBe(null);
    });
  });
});
