// Mock the database's pool and query function
jest.mock("../../config/database/database.config", () => {
  const queryMock = jest.fn(); // Mock query function
  return { pool: { query: queryMock } }; // Return the mocked pool directly
});

const { pool } = require("../../config/database/database.config");
const { addContact } = require("../../repository/contactRepository");

/*
Test methods for peopleRepository
*/
describe("Testing peopleRepository.js", () => {
  // mock contact value to use while testing
  const mockContact = {
    contactNumber: "1234567890",
    contactType: "mobile",
    preferredContact: true,
  };
  const mockPeopleId = 1;

  /*
  Tests for the addContact method
  */
  describe("addContact Tests", () => {
    it("insert a contact with no errors", async () => {
      // Mock the database to return a success response
      const mockResults = { affectedRows: 1 };
      pool.query.mockResolvedValueOnce([mockResults]);

      // Call addContact
      const result = await addContact(mockContact, mockPeopleId);

      // Verify the SQL query and parameters
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        1,
        "1234567890",
        "mobile",
        true,
      ]);

      // Expect function to return the database result
      expect(result).toBe(mockResults);
    });

    it("handle errors if the query fails", async () => {
      // Mock the database to throw an error
      const mockError = new Error("Database query failed");
      pool.query.mockRejectedValueOnce(mockError);

      // Call addContact and expect it to handle the error
      const result = await addContact(mockContact, mockPeopleId);
      expect(result).toBe(null);
    });
  });
});
