// Mock the database's pool and query function
jest.mock("../../config/database/database.config", () => {
  const queryMock = jest.fn(); // Mock query function
  return { pool: { query: queryMock } }; // Return the mocked pool directly
});

const { pool } = require("../../config/database/database.config");
const { addPerson } = require("../../repository/peopleRepository");

/*
Test methods for peopleRepository
*/
describe("Testing peopleRepository.js", () => {
  // mock person for testing
  const mockPerson = {
    firstName: "John",
    lastName: "Doe",
    middleName: "A",
    maidenName: null,
    suffix: null,
    nickName: "Johnny",
    techAlumniChapter: "Tidewater AC",
    classYear: "2024",
    gradYear: "2024",
    gradSemester: "spring",
    gender: "male",
  };

  /*
  Tests for the addPerson method
  */
  describe("addPerson Tests", () => {
    it("Insert works with no errors", async () => {
      // Mock the database to return the new insert ID as 1
      const mockInsertId = 1;
      pool.query.mockResolvedValueOnce([{ insertId: mockInsertId }]);

      // call add person
      const result = await addPerson(mockPerson);

      // Verify the SQL query and parameters
      expect(pool.query).toHaveBeenCalledWith(expect.any(String), [
        "John",
        "Doe",
        "A",
        null,
        null,
        "Johnny",
        2, // hardcoded for now
        "2024",
        "2024",
        "spring",
        "male",
      ]);

      // expect function to return the new insert id
      expect(result).toBe(mockInsertId);
    });

    it("insert throws an error if query fails", async () => {
      // Mock the database to throw an error
      const mockError = new Error("Database query failed");
      pool.query.mockRejectedValueOnce(mockError);

      // call addPerson and expect it to handle the error
      const result = await addPerson(mockPerson);
      expect(result).toBe(null);
    });
  });
});
