import React, { useEffect, useState } from "react";
import axios from "axios";
import "./Home.css"; // If you want to add styling later
import logo from "../assets/corps_logo.png";
import { jwtDecode } from "jwt-decode";

/*
Home page where users will be redirected after log in or continuing as a guest
*/
function Home() {
  // username and privilage to be extracted from JWT token
  const [username, setUsername] = useState("");
  const [privilege, setPrivilege] = useState("");

  const extractTokenFromUrl = () => {
    const params = new URLSearchParams(window.location.search);
    const token = params.get("token");

    // no token found
    if (!token) {
      // user will be seen as a guest
      setUsername("guest");
      setPrivilege("guest");
    }

    // decode the token and set the user info
    try {
      const decoded = jwtDecode(token);
      setUsername(decoded.username);
      setPrivilege(decoded.role);
    } catch (error) {
      console.error("Error decoding token: ", error);
    }
  };

  // useEffect to make the API call
  useEffect(() => {
    extractTokenFromUrl(); // extract the username and role from the token
  }, []);

  return (
    // <div>
    //   <h1>Home Page</h1>

    //   <p>
    //     Below are the results of calling the backend server. The API URL should
    //     be localhost in development and be
    //     http://corpsdirectory.discovery.cs.vt.edu/api in the cluster.
    //   </p>

    //   {/* Display data if it exists */}
    //   <p>
    //     Data: {data ? <span>{JSON.stringify(data)}</span> : <span>&nbsp;</span>}
    //   </p>

    //   <p>API URL: {process.env.REACT_APP_API_URL}</p>

    //   {/* display error if there is an error*/}
    //   <p>Error: {error ? <span>{error}</span> : <span>&nbsp;</span>}</p>
    // </div>
    <>
      <div className="text-center">
        <h1 className="thin-veranda">VT Cadet Directory</h1>
        <h1 className="bold-veranda">Connect to any Cadet</h1>
      </div>
      <div className="containerB">
        <div className="description-section">
          <div className="transparent-box-text">
            <h1 className="title-font">
              Virginia Tech Corps of Cadets Directory
            </h1>
            {/*Adding this here so you guys see how to access but feel free to change it*/}
            {username && (
              <div>
                <h2>
                  Welcome, <strong>{username}</strong>!
                </h2>
                <p>
                  Your role: <strong>{privilege}</strong>
                </p>
              </div>
            )}
            <h1 className="description-font">
              Lorem ipsum odor amet, consectetuer adipiscing elit. Primis quam
              vel posuere lobortis inceptos. Nostra sociosqu tristique sagittis
              iaculis velit morbi lobortis. Maecenas vivamus consectetur
              vestibulum adipiscing neque. Sollicitudin ornare nam sapien class
              ex velit in. Senectus pretium quisque cras phasellus sociosqu
              malesuada. Sapien pretium viverra adipiscing est libero aliquam.
              Cursus conubia a volutpat condimentum libero sed. Vulputate velit
              purus posuere amet class ut.
              <br />
              <br />
              Conubia mauris curabitur bibendum quisque justo dapibus potenti.
              Sem cubilia quisque in donec ipsum sem. Elit risus convallis
              ornare dis pharetra senectus. Sit sodales cursus mattis taciti
              purus vel suscipit proin. Cursus metus euismod primis sit praesent
              magnis phasellus. Ut sagittis inceptos pretium sociosqu bibendum,
              at tempus adipiscing. Ac elementum rhoncus egestas viverra commodo
              cursus turpis lectus torquent.
            </h1>
          </div>
        </div>
        <div className="transparent-box-image">
          <img src={logo} alt="Corps Logo" className="logo" width={400} />
        </div>
      </div>
      <div className="selection-section">
        <div className="button-container">
          <div className="button-wrapper">
            <button className="action-button">
              <img src={logo} width={70} alt="Browse" className="icon" />
            </button>
            <span>Browse</span>
          </div>
          <div className="button-wrapper">
            <button className="action-button">
              <img src={logo} alt="Search" className="icon" />
            </button>
            <span>Search</span>
          </div>
          <div className="button-wrapper">
            <button className="action-button">
              <img src={logo} alt="Message" className="icon" />
            </button>
            <span>Message</span>
          </div>
        </div>
      </div>
    </>
  );
}

export default Home;
